@@ -52,7 +52,7 @@ plot.cvrisk <- function(x, ylab = attr(x, "risk"), ylim = range(x),
     out <- apply(x, 1, function(y) lines(1:ncol(x),y, col = "lightgrey"))
     rm(out)
     ms <- which.min(cm)
-    lines(c(ms, ms), c(0, cm[ms]), lty = 2)
+    lines(c(ms, ms), c(min(c(0, ylim[1] * ifelse(ylim[1] < 0, 2, 0.5))), cm[ms]), lty = 2)
     lines(1:ncol(x), cm, type = "b")
 }
 
